@@ -104,7 +104,7 @@ def create_vpc(cluster):
     cluster.vpc = _create_vpc(vpc_name, ec2)
     cluster.vpc.name = vpc_name
     cluster.vpc.cluster_name = cluster.name
-    _create_tags(cluster.vpc, cluster.vpc)
+    _apply_bright_tags(cluster.vpc, cluster.vpc)
 
     if config["configure_igw"]:
         internet_gateway = _create_internet_gateway(cluster.vpc, ec2)
@@ -165,7 +165,7 @@ def _create_internet_gateway(vpc, ec2):
     time.sleep(0.5)
 
     internet_gateway.name = vpc.cluster_name
-    _create_tags(vpc, internet_gateway)
+    _apply_bright_tags(vpc, internet_gateway)
 
     vpc.attach_internet_gateway(InternetGatewayId=internet_gateway.id)
     return internet_gateway
@@ -179,11 +179,14 @@ def _create_public_subnet(vpc, ec2):
     if config["aws_availability_zone"]:
         kwargs["AvailabilityZone"] = config["aws_availability_zone"]
 
+    public_subnet_name = vpc.cluster_name + " public"
+    tags = _construct_bright_tags(vpc, public_subnet_name, BCM_TYPE_HEAD_NODE)
+    kwargs["TagSpecifications"] = [{"ResourceType": "subnet", "Tags": tags}]
+
     public_subnet = vpc.create_subnet(**kwargs)
     time.sleep(0.5)
+    public_subnet.name = public_subnet_name
 
-    public_subnet.name = vpc.cluster_name + " public"
-    _create_tags(vpc, public_subnet)
     return public_subnet
 
 
@@ -195,11 +198,14 @@ def _create_private_subnet(vpc, ec2):
     if config["aws_availability_zone"]:
         kwargs["AvailabilityZone"] = config["aws_availability_zone"]
 
+    private_subnet_name = vpc.cluster_name + " private"
+    tags = _construct_bright_tags(vpc, private_subnet_name, BCM_TYPE_HEAD_NODE)
+    kwargs["TagSpecifications"] = [{"ResourceType": "subnet", "Tags": tags}]
+
     private_subnet = vpc.create_subnet(**kwargs)
     time.sleep(0.5)
+    private_subnet.name = private_subnet_name
 
-    private_subnet.name = vpc.cluster_name + " private"
-    _create_tags(vpc, private_subnet)
     return private_subnet
 
 
@@ -222,7 +228,7 @@ def _set_default_gateway_vpc(vpc, internet_gateway):
 def _set_default_gateway_subnet(vpc, subnet, internet_gateway):
     route_table = vpc.create_route_table()
     route_table.name = subnet.name + " route table"
-    _create_tags(vpc, route_table)
+    _apply_bright_tags(vpc, route_table)
 
     route_table.associate_with_subnet(SubnetId=subnet.id)
 
@@ -345,6 +351,11 @@ def _create_head_node(vpc, hostname, public_subnet, head_node_image, head_node_s
     kwargs["SecurityGroupIds"] = [head_node_sg_id]
 
     log.info("Creating the head node VM instance")
+
+    head_node_instance_name = f"{vpc.cluster_name} (Bright COD-AWS {config['version']} head node)"
+    tags = _construct_bright_tags(vpc, head_node_instance_name, BCM_TYPE_HEAD_NODE)
+    kwargs["TagSpecifications"] = [{"ResourceType": "instance", "Tags": tags}]
+
     instances = public_subnet.create_instances(**kwargs)
     head_node_instance = instances[0]
     log.info(f"Created VM {head_node_instance.id}")
@@ -353,8 +364,6 @@ def _create_head_node(vpc, hostname, public_subnet, head_node_image, head_node_s
     _retry_not_found(head_node_instance.wait_until_exists)
 
     log.debug("Applying tags to the head node VM instance")
-    head_node_instance.name = f"{vpc.cluster_name} (Bright COD-AWS {config['version']} head node)"
-    _create_tags(vpc, head_node_instance, BCM_TYPE_HEAD_NODE)
     return head_node_instance
 
 
@@ -438,7 +447,7 @@ def _find_main_route_table(vpc):
     return route_tables[0]
 
 
-def _create_tags(vpc, obj, bcm_type=None):
+def _construct_bright_tags(vpc, obj_name, bcm_type=None):
     tags = {
         "BCM Created at": datetime.utcnow().isoformat() + "Z",  # fix missing timezone
         "BCM Created by": utils.get_user_at_fqdn_hostname(),
@@ -446,15 +455,19 @@ def _create_tags(vpc, obj, bcm_type=None):
         "BCM Bursting": "on-demand",
         # This one has to follow a slightly different naming convention (i.e. no "BCM"
         # prefix), because this tag has a special meaning for AWS.
-        "Name": obj.name
+        "Name": obj_name
     }
     if bcm_type:
         tags["BCM Type"] = bcm_type
 
     tags.update(dict((str(k), str(v)) for k, v in config["cluster_tags"]))
     tags = [{"Key": key, "Value": value} for key, value in six.iteritems(tags)]
-    res = _retry_not_found(obj.create_tags, Tags=tags)
-    log.debug("create tag response: %s", res)
+    return tags
+
+
+def _apply_bright_tags(vpc, obj, bcm_type=None):
+    tags = _construct_bright_tags(vpc, obj.name, bcm_type)
+    _retry_not_found(obj.create_tags, Tags=tags)
 
 
 def get_aws_tag(tags: List[Dict[str, str]], name: str, default: str = None) -> str:
